==> Paws-0.01.tar.gz: Paws-0.01/lib/Paws/RedShift/DisableSnapshotCopy.pm <==

package Paws::RedShift::DisableSnapshotCopy {
  use Moose;
  has ClusterIdentifier => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisableSnapshotCopy');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::RedShift::DisableSnapshotCopyResult');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'DisableSnapshotCopyResult');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::DisableSnapshotCopy - Arguments for method DisableSnapshotCopy on Paws::RedShift

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisableSnapshotCopy on the 
Amazon Redshift service. Use the attributes of this class
as arguments to method DisableSnapshotCopy.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DisableSnapshotCopy.

As an example:

  $service_obj->DisableSnapshotCopy(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> ClusterIdentifier => Str

  

The unique identifier of the source cluster that you want to disable
copying of snapshots to a destination region.

Constraints: Must be the valid name of an existing cluster that has
cross-region snapshot copy enabled.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for DisableSnapshotCopy in Paws::RedShift

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.09.tar.gz: Paws-0.09/lib/Paws/RedShift/DisableSnapshotCopy.pm <==

package Paws::RedShift::DisableSnapshotCopy {
  use Moose;
  has ClusterIdentifier => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisableSnapshotCopy');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::RedShift::DisableSnapshotCopyResult');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'DisableSnapshotCopyResult');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::DisableSnapshotCopy - Arguments for method DisableSnapshotCopy on Paws::RedShift

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisableSnapshotCopy on the 
Amazon Redshift service. Use the attributes of this class
as arguments to method DisableSnapshotCopy.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DisableSnapshotCopy.

As an example:

  $service_obj->DisableSnapshotCopy(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> ClusterIdentifier => Str

  

The unique identifier of the source cluster that you want to disable
copying of snapshots to a destination region.

Constraints: Must be the valid name of an existing cluster that has
cross-region snapshot copy enabled.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisableSnapshotCopy in L<Paws::RedShift>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
